@@ -14,16 +14,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import click
 import requests
 from treelib import Tree
 
 from gophian.__about__ import BUGS_URL
-from gophian.error import ExecutionError
+from gophian.error import ExecutionError, GophianError
 from gophian.packages import DebianGolangPackages
 from gophian.session import Session
+from gophian.trace import trace
 from gophian.vcs import package_from_import_path
 
 
@@ -53,6 +54,7 @@ from gophian.vcs import package_from_import_path
     "--max-depth",
     required=False,
     help="Maximum recursion depth of unpackaged dependencies.",
+    type=int,
 )
 @click.pass_context
 def estimate(
@@ -118,7 +120,7 @@ def estimate(
 def dependency_tree(
     session: Session,
     seen: List[str],
-    errors: List[ExecutionError],
+    errors: List[Union[ExecutionError, GophianError]],
     package: str,
     include_packaged_deps: bool,
     include_version_conflicts: bool,
@@ -128,9 +130,23 @@ def dependency_tree(
     level: int = 1,
 ):
     try:
+        trace("Fetching package: " + package)
         go_package = session.go_get(package)
+        trace("Finding dependencies: " + package)
         dep_packages = go_package.find_dependencies()
+        trace("Found dependencies: " + package)
+        trace(dep_packages)
     except ExecutionError as error:
+        trace("Execution error: " + package)
+        errors.append(error)
+        tree.create_node(
+            click.style("Error getting dependencies", fg="red"),
+            f"{package}_error",
+            parent=package,
+        )
+        return
+    except GophianError as error:
+        trace("Gophian error: " + package)
         errors.append(error)
         tree.create_node(
             click.style("Error getting dependencies", fg="red"),
@@ -139,17 +155,70 @@ def dependency_tree(
         )
         return
     for dep_package, _ in dep_packages:
-        if (
-            (result := debian_packages.library_is_packaged(dep_package))
-            and (debian_package := result[0])
-            and (debian_package_version := result[1])
-        ):
-            if include_packaged_deps:
-                node_text = click.style(
-                    f"{dep_package} ({debian_package})",
-                    fg="green",
+        result = debian_packages.library_is_packaged(dep_package)
+        if result is None:
+            try:
+                dep_go_package = session.go_get(dep_package)
+            except ExecutionError as error:
+                trace("Execution error: " + package)
+                errors.append(error)
+                tree.create_node(
+                    dep_package,
+                    f"{package}_{dep_package}",
+                    parent=package,
                 )
+                tree.create_node(
+                    click.style("Error fetching package", fg="red"),
+                    f"{package}_{dep_package}_error",
+                    parent=f"{package}_{dep_package}",
+                )
+                continue
+            except GophianError as error:
+                trace("Gophian error: " + package)
+                errors.append(error)
+                tree.create_node(
+                    dep_package,
+                    f"{package}_{dep_package}",
+                    parent=package,
+                )
+                tree.create_node(
+                    click.style("Error fetching package", fg="red"),
+                    f"{package}_{dep_package}_error",
+                    parent=f"{package}_{dep_package}",
+                )
+                continue
+            # This handles the case where the module has a version suffix
+            # e.g. github/go-git/go-billy/v5
+            if (
+                dep_go_package.module != dep_package
+                and dep_go_package.module.startswith(dep_package + "/")
+            ):
+                result = debian_packages.library_is_packaged(dep_go_package.module)
+        if result is not None:
+            trace(dep_package + " is packaged in Debian")
+            debian_package, debian_package_version, suite = result
+            if include_packaged_deps:
+                trace(dep_package + " will be included in output")
+                if suite == "experimental":
+                    trace(dep_package + " is in experimental")
+                    node_text = click.style(
+                        f"{dep_package} ({debian_package}) [experimental]",
+                        fg="green",
+                    )
+                elif suite == "NEW":
+                    trace(dep_package + " is in NEW")
+                    node_text = click.style(
+                        f"{dep_package} ({debian_package}) [NEW]",
+                        fg="blue",
+                    )
+                else:
+                    trace(dep_package + " is in unstable")
+                    node_text = click.style(
+                        f"{dep_package} ({debian_package})",
+                        fg="bright_green",
+                    )
                 if include_version_conflicts:
+                    trace(dep_package + " will be checked for version conflicts")
                     [go_mod_major, go_mod_minor] = go_package.deps[
                         dep_package
                     ].vstring.split(".")[:2]
@@ -165,6 +234,11 @@ def dependency_tree(
                         or (go_mod_major != debian_major)
                         or (go_mod_major == 0 and go_mod_minor != debian_minor)
                     ):
+                        trace(
+                            dep_package
+                            + " has a version conflict: "
+                            + f"[{debian_package_version} ≠ {go_package.deps[dep_package]}]"
+                        )
                         node_text += click.style(
                             f" [{debian_package_version} ≠ {go_package.deps[dep_package]}]",
                             fg="yellow",
@@ -175,27 +249,31 @@ def dependency_tree(
                     parent=package,
                 )
         elif dep_package in seen:
+            trace(dep_package + " has already been seen")
             tree.create_node(
-                f"{dep_package}",
+                click.style(dep_package, fg="black"),
                 f"{package}_{dep_package}",
                 parent=package,
             )
-        elif max_depth is None or (level + 1) > max_depth:
+        else:
+            trace(dep_package + " is not in Debian")
+            trace("Depth reached: " + str(level) + " < " + str(max_depth))
             tree.create_node(
                 dep_package,
                 dep_package,
                 parent=package,
             )
             seen.append(dep_package)
-            dependency_tree(
-                session,
-                seen,
-                errors,
-                dep_package,
-                include_packaged_deps,
-                include_version_conflicts,
-                debian_packages,
-                tree,
-                max_depth,
-                level + 1,
-            )
+            if max_depth is None or level < max_depth:
+                dependency_tree(
+                    session,
+                    seen,
+                    errors,
+                    dep_package,
+                    include_packaged_deps,
+                    include_version_conflicts,
+                    debian_packages,
+                    tree,
+                    max_depth,
+                    level + 1,
+                )
