@@ -15,7 +15,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 from pathlib import Path
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import click
 import graphviz
@@ -23,11 +23,12 @@ import requests
 from graphviz.dot import Dot
 
 from gophian.__about__ import BUGS_URL
-from gophian.error import ExecutionError
+from gophian.error import ExecutionError, GophianError
 from gophian.hosts import KNOWN_HOSTS
 from gophian.name import debianize_name, shorten_host
 from gophian.packages import DebianGolangPackages
 from gophian.session import Session
+from gophian.trace import trace
 from gophian.vcs import package_from_import_path
 
 
@@ -74,6 +75,7 @@ from gophian.vcs import package_from_import_path
     "--max-depth",
     required=False,
     help="Maximum recursion depth of unpackaged dependencies.",
+    type=int,
 )
 @click.pass_context
 def estimate_graphviz(
@@ -168,7 +170,7 @@ def estimate_graphviz(
 def dependency_tree(
     session: Session,
     seen: List[str],
-    errors: List[ExecutionError],
+    errors: List[Union[ExecutionError, GophianError]],
     package: str,
     include_packaged_deps: bool,
     include_version_conflicts: bool,
@@ -178,29 +180,67 @@ def dependency_tree(
     level: int = 1,
 ):
     try:
+        trace("Fetching package: " + package)
         go_package = session.go_get(package)
+        trace("Finding dependencies: " + package)
         dep_packages = go_package.find_dependencies()
+        trace("Found dependencies: " + package)
+        trace(dep_packages)
     except ExecutionError as error:
+        trace("Execution error: " + package)
+        errors.append(error)
+        click.secho("Error getting dependencies for " + package, fg="red")
+        dot.node(package, package + "\\n(Error getting dependencies)")
+        return
+    except GophianError as error:
+        trace("Gophian error: " + package)
         errors.append(error)
         click.secho("Error getting dependencies for " + package, fg="red")
         dot.node(package, package + "\\n(Error getting dependencies)")
         return
     for dep_package, _ in dep_packages:
-        if (
-            (result := debian_packages.library_is_packaged(dep_package))
-            and (debian_package := result[0])
-            and (debian_package_version := result[1])
-        ):
+        result = debian_packages.library_is_packaged(dep_package)
+        if result is None:
+            try:
+                dep_go_package = session.go_get(dep_package)
+            except ExecutionError as error:
+                trace("Execution error: " + package)
+                errors.append(error)
+                click.secho("Error fetching package " + package, fg="red")
+                dot.node(package, package + "\\n(Error fetching package)")
+                continue
+            except GophianError as error:
+                trace("Gophian error: " + package)
+                errors.append(error)
+                click.secho("Error fetching package " + package, fg="red")
+                dot.node(package, package + "\\n(Error fetching package)")
+                continue
+            # This handles the case where the module has a version suffix
+            # e.g. github/go-git/go-billy/v5
+            if (
+                dep_go_package.module != dep_package
+                and dep_go_package.module.startswith(dep_package + "/")
+            ):
+                result = debian_packages.library_is_packaged(dep_go_package.module)
+        if result is not None:
+            trace(dep_package + " is packaged in Debian")
+            debian_package, debian_package_version, suite = result
             if include_packaged_deps:
+                trace(dep_package + " will be included in output")
                 if dep_package not in seen:
+                    trace(dep_package + " is in " + suite)
+                    suite_text = ""
+                    if suite == "experimental" or suite == "NEW":
+                        suite_text = f"\n[{suite}]"
                     dot.node(
                         dep_package,
-                        f"{dep_package}\\n({debian_package})",
+                        f"{dep_package}\\n({debian_package}){suite_text}",
                         fillcolor="green",
                         style="filled",
                     )
                 label = ""
                 if include_version_conflicts:
+                    trace(dep_package + " will be checked for version conflicts")
                     [go_mod_major, go_mod_minor] = go_package.deps[
                         dep_package
                     ].vstring.split(".")[:2]
@@ -216,6 +256,11 @@ def dependency_tree(
                         or (go_mod_major != debian_major)
                         or (go_mod_major == 0 and go_mod_minor != debian_minor)
                     ):
+                        trace(
+                            dep_package
+                            + " has a version conflict: "
+                            + f"[{debian_package_version} ≠ {go_package.deps[dep_package]}]"
+                        )
                         label = (
                             f"{debian_package_version} ≠ {go_package.deps[dep_package]}"
                         )
@@ -223,20 +268,24 @@ def dependency_tree(
                 if dep_package not in seen:
                     seen.append(dep_package)
         elif dep_package in seen:
+            trace(dep_package + " has already been seen")
             dot.edge(package, dep_package)
-        elif max_depth is None or (level + 1) > max_depth:
+        else:
+            trace(dep_package + " is not in Debian")
+            trace("Depth reached: " + str(level) + " < " + str(max_depth))
             dot.node(dep_package, fillcolor="white", style="filled")
             dot.edge(package, dep_package)
             seen.append(dep_package)
-            dependency_tree(
-                session,
-                seen,
-                errors,
-                dep_package,
-                include_packaged_deps,
-                include_version_conflicts,
-                debian_packages,
-                dot,
-                max_depth,
-                level + 1,
-            )
+            if max_depth is None or level < max_depth:
+                dependency_tree(
+                    session,
+                    seen,
+                    errors,
+                    dep_package,
+                    include_packaged_deps,
+                    include_version_conflicts,
+                    debian_packages,
+                    dot,
+                    max_depth,
+                    level + 1,
+                )
