@@ -250,6 +250,12 @@ def make(
                 ).ask()
                 if selected_binaries is None:
                     raise click.Abort()
+                if len(selected_binaries) == 0:
+                    package_type = PackageType.LIBRARY
+                    click.secho(
+                        "You have not selected any binaries; switching package type to library only.",
+                        fg="yellow",
+                    )
             else:
                 selected_binaries = all_binaries
 
@@ -385,6 +391,12 @@ def make(
                     debian_package := result[0]
                 ):
                     debian_deps.append(debian_package)
+                    if result[2] != "unstable":
+                        if not quiet:
+                            click.secho(
+                                f"Dependency {dep} ({debian_package}) is in {result[2]}.",
+                                fg="bright_blue",
+                            )
                 else:
                     missing_deps.append(dep)
 
@@ -399,6 +411,12 @@ def make(
                 ):
                     if debian_package not in debian_deps:
                         debian_build_deps.append(debian_package + " <!nocheck>")
+                        if result[2] != "unstable":
+                            if not quiet:
+                                click.secho(
+                                    f"Test dependency {dep} ({debian_package}) is in {result[2]}.",
+                                    fg="bright_blue",
+                                )
                     else:
                         continue
                 else:
