@@ -24,6 +24,7 @@ from looseversion import LooseVersion
 from gophian.error import GophianError
 from gophian.new import NewPackage
 from gophian.salsa import salsa_repo_exists
+from gophian.trace import trace
 
 
 DEB_EXT = re.compile(r"([\+~](debian|dfsg|ds|deb)(\.)?(\d+)?)?-([A-Za-z0-9\+\.~]+)$")
@@ -54,15 +55,17 @@ class DebianPackage:
         else:
             return None
 
-    def is_in_new_queue(self) -> Optional[NewPackage]:
+    def is_in_new_queue(self) -> Optional[str]:
         """
         Check if the Debian package is in the NEW queue.
 
         Returns NewPackage object if found.
         """
-        return NewPackage.get(self.session, self.source)
+        new_package = NewPackage.get(self.session, self.source)
+        if new_package:
+            return DEB_EXT.sub("", new_package.version)
 
-    def unstable_version(self) -> Optional[str]:
+    def unstable_version(self) -> Optional[Tuple[str, str]]:
         """
         Check if the Debian package is currently in unstable.
         Useful to check if a package has been removed.
@@ -80,14 +83,12 @@ class DebianPackage:
         # sources api returns status code 200 but body {error:404}
         if res.status_code == 404 or ("error" in data and data["error"] == 404):
             return
-        return (
-            DEB_EXT.sub("", data["versions"][0]["version"])
-            if (
-                "sid" in data["versions"][0]["suites"]
-                or "experimental" in data["versions"][0]["suites"]
-            )
-            else None
-        )
+        in_unstable = "sid" in data["versions"][0]["suites"]
+        in_experimental = "experimental" in data["versions"][0]["suites"]
+        if in_unstable or in_experimental:
+            return DEB_EXT.sub("", data["versions"][0]["version"]), "experimental" if (
+                in_experimental and not in_unstable
+            ) else "unstable"
 
 
 class DebianGolangPackages:
@@ -101,6 +102,7 @@ class DebianGolangPackages:
         def filter_dbgsym(package):
             return not package["binary"].endswith("-dbgsym")
 
+        trace("Fetching list of Go packages in Debian")
         self.packages = list(
             filter(
                 filter_dbgsym,
@@ -136,22 +138,31 @@ class DebianGolangPackages:
 
     def library_is_packaged(
         self, go_package: str
-    ) -> Optional[Tuple[str, LooseVersion]]:
+    ) -> Optional[Tuple[str, LooseVersion, str]]:
         """
         Check if the given Go library has been packaged for Debian.
         """
-        for deb_package in self.packages:
-            if not deb_package["binary"].endswith("-dev"):
+        trace("Checking if package is in Debian: " + go_package)
+        for deb_package_data in self.packages:
+            if not deb_package_data["binary"].endswith("-dev"):
                 continue
-            if (
-                deb_package["metadata_value"] == go_package
-                or go_package.startswith(deb_package["metadata_value"] + "/")
-            ) and (
-                version := DebianPackage(
-                    self.session, deb_package["source"]
-                ).unstable_version()
+            if deb_package_data[
+                "metadata_value"
+            ] == go_package or go_package.startswith(
+                deb_package_data["metadata_value"] + "/"
             ):
-                return deb_package["binary"], LooseVersion(version)
+                deb_package = DebianPackage(self.session, deb_package_data["source"])
+                trace("Found package in Debian: " + deb_package.source)
+                if result := deb_package.unstable_version():
+                    trace("Package is in unstable: " + deb_package.source)
+                    return (
+                        deb_package_data["binary"],
+                        LooseVersion(result[0]),
+                        result[1],
+                    )
+                elif version := deb_package.is_in_new_queue():
+                    trace("Package is in NEW: " + deb_package.source)
+                    return deb_package_data["binary"], LooseVersion(version), "NEW"
         return None
 
     def _check_for_package(self, package_name: str, quiet: bool = False) -> bool:
@@ -162,8 +173,12 @@ class DebianGolangPackages:
                 )
                 package = DebianPackage(self.session, debian_package)
                 if package.is_in_package_tracker():
-                    if version := package.unstable_version():
-                        click.echo("Latest version in Debian repos is " + version)
+                    if result := package.unstable_version():
+                        click.echo(
+                            "Latest version in Debian repos is "
+                            + result[0]
+                            + f" ({result[1]})"
+                        )
                         click.echo("https://tracker.debian.org/pkg/" + debian_package)
                     else:
                         click.echo("Package was removed from Debian unstable")
