@@ -25,6 +25,7 @@ from looseversion import LooseVersion
 
 from gophian.error import GophianError
 from gophian.git import Git
+from gophian.trace import trace
 from gophian.vcs import package_from_import_path
 
 if TYPE_CHECKING:
@@ -35,6 +36,10 @@ GO_MOD_GO_REGEX = re.compile(r"^go (\d[\d\.]*)$")
 GO_MOD_REQUIREMENT_REGEX = re.compile(r"^(\S+) (\S+)(?: //.*)?$")
 GO_MOD_NONVERSIONED_REGEX = re.compile(r"^(\d[\d\.]*)?-(\d{14})-([a-z\d]{12})$")
 
+GO_ERROR_NO_MATCHING_FILES = re.compile(
+    r"^([^:]+):(\d+):\d+: pattern [^:]+: no matching files found$"
+)
+
 IGNORE_LIST = (Path(__file__).parent / "ignore.txt").read_text().splitlines()
 
 
@@ -89,10 +94,16 @@ class GoPackage(Git):
                             if comment_index := line.find("//") != -1:
                                 line = line[:comment_index].strip()
                             if not indirect:
-                                dep, _ = package_from_import_path(
-                                    self.session.requests_session, match.group(1)
-                                )
-                                self.deps[dep] = GoVersion(match.group(2))
+                                try:
+                                    dep, _ = package_from_import_path(
+                                        self.session.requests_session, match.group(1)
+                                    )
+                                    self.deps[dep] = GoVersion(match.group(2))
+                                except Exception as e:
+                                    click.echo(
+                                        click.style("Error: ", bold=True, fg="red")
+                                        + str(e)
+                                    )
                         elif line == ")":
                             inside_require = False
                         else:
@@ -112,11 +123,21 @@ class GoPackage(Git):
                                     line = line[1:-1]
                                     if match := GO_MOD_REQUIREMENT_REGEX.match(line):
                                         if not indirect:
-                                            dep, _ = package_from_import_path(
-                                                self.session.requests_session,
-                                                match.group(1),
-                                            )
-                                            self.deps[dep] = GoVersion(match.group(2))
+                                            try:
+                                                dep, _ = package_from_import_path(
+                                                    self.session.requests_session,
+                                                    match.group(1),
+                                                )
+                                                self.deps[dep] = GoVersion(
+                                                    match.group(2)
+                                                )
+                                            except Exception as e:
+                                                click.echo(
+                                                    click.style(
+                                                        "Error: ", bold=True, fg="red"
+                                                    )
+                                                    + str(e)
+                                                )
                                     else:
                                         raise GoModParseError(
                                             i + 1,
@@ -126,11 +147,21 @@ class GoPackage(Git):
                                 else:
                                     if match := GO_MOD_REQUIREMENT_REGEX.match(line):
                                         if not indirect:
-                                            dep, _ = package_from_import_path(
-                                                self.session.requests_session,
-                                                match.group(1),
-                                            )
-                                            self.deps[dep] = GoVersion(match.group(2))
+                                            try:
+                                                dep, _ = package_from_import_path(
+                                                    self.session.requests_session,
+                                                    match.group(1),
+                                                )
+                                                self.deps[dep] = GoVersion(
+                                                    match.group(2)
+                                                )
+                                            except Exception as e:
+                                                click.echo(
+                                                    click.style(
+                                                        "Error: ", bold=True, fg="red"
+                                                    )
+                                                    + str(e)
+                                                )
                                     else:
                                         raise GoModParseError(
                                             i + 1,
@@ -161,6 +192,24 @@ class GoPackage(Git):
         )
         # Ignore errors from go, as they're about missing dependencies in
         # GOPATH (and we don't care about this).
+        # Except when an error regarding a go:embed directive affects output.
+        redo = False
+        for line in out.stderr.splitlines():
+            if match := GO_ERROR_NO_MATCHING_FILES.match(line.decode("utf-8")):
+                redo = True
+                affected_file = match.group(1)
+                affected_lineno = int(match.group(2))
+                path = self.session.gopath / "src" / self.package / affected_file
+                s = path.read_text().splitlines()
+                s[affected_lineno - 1] = "// embed removed"
+                path.write_text("\n".join(s))
+        if redo:
+            trace(
+                self.package
+                + ": Error with go:embed detected, removing problematic directives."
+            )
+            return self.find_dependencies(test)
+
         for pkg in out.stdout.splitlines():
             dep_string = pkg.strip().decode()[1:-1]
             all_imports += dep_string.split(" ")
@@ -189,7 +238,7 @@ class GoPackage(Git):
                     package_from_import_path(self.session.requests_session, imp)
                 )
             except Exception as e:
-                click.echo(e)
+                click.echo(click.style("Error: ", bold=True, fg="red") + str(e))
                 continue
 
         return deps
